@@ -182,6 +182,8 @@ gedit_app_dispose (GObject *object)
 	g_clear_object (&app->priv->engine);
 
 	g_clear_object (&app->priv->window_menu);
+	g_clear_object (&app->priv->notebook_menu);
+	g_clear_object (&app->priv->tab_width_menu);
 
 	G_OBJECT_CLASS (gedit_app_parent_class)->dispose (object);
 }
@@ -402,6 +404,22 @@ gedit_app_has_app_menu (GeditApp *app)
 	return show_app_menu && !show_menubar;
 }
 
+static void
+load_accels (void)
+{
+	gchar *filename;
+
+	filename = g_build_filename (gedit_dirs_get_user_config_dir (),
+				     "accels",
+				     NULL);
+	if (filename != NULL)
+	{
+		gedit_debug_message (DEBUG_APP, "Loading keybindings from %s\n", filename);
+		gtk_accel_map_load (filename);
+		g_free (filename);
+	}
+}
+
 static void
 gedit_app_startup (GApplication *application)
 {
@@ -467,7 +485,6 @@ gedit_app_startup (GApplication *application)
 	}
 	else
 	{
-
 		if (gedit_app_has_app_menu (app))
 		{
 			GMenuModel *appmenu;
@@ -489,6 +506,8 @@ gedit_app_startup (GApplication *application)
 	g_object_unref (builder);
 
 	/* Accelerators */
+	gtk_application_add_accelerator (GTK_APPLICATION (application),
+					 "<Primary>N", "app.new-window", NULL);
 	gtk_application_add_accelerator (GTK_APPLICATION (application),
 	                                 "<Primary>Q", "app.quit", NULL);
 	gtk_application_add_accelerator (GTK_APPLICATION (application),
@@ -545,6 +564,8 @@ gedit_app_startup (GApplication *application)
 	                                 "<Primary><Alt>Page_Down",
 	                                 "win.next-document", NULL);
 
+	load_accels ();
+
 	/* Load custom css */
 	error = NULL;
 	css_file = g_file_new_for_uri ("resource:///org/gnome/gedit/ui/gedit-style.css");
@@ -554,12 +575,14 @@ gedit_app_startup (GApplication *application)
 		gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
 		                                           GTK_STYLE_PROVIDER (provider),
 		                                           GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+		g_object_unref (provider);
 	}
 	else
 	{
 		g_warning ("Could not load css provider: %s", error->message);
 		g_error_free (error);
 	}
+	g_object_unref (css_file);
 
 	/*
 	 * We use the default gtksourceview style scheme manager so that plugins
@@ -1072,30 +1095,6 @@ gedit_app_shutdown (GApplication *app)
 	G_APPLICATION_CLASS (gedit_app_parent_class)->shutdown (app);
 }
 
-static void
-load_accels (void)
-{
-	gchar *filename;
-
-	filename = g_build_filename (gedit_dirs_get_user_config_dir (),
-				     "accels",
-				     NULL);
-	if (filename != NULL)
-	{
-		gedit_debug_message (DEBUG_APP, "Loading keybindings from %s\n", filename);
-		gtk_accel_map_load (filename);
-		g_free (filename);
-	}
-}
-
-static void
-gedit_app_constructed (GObject *object)
-{
-	G_OBJECT_CLASS (gedit_app_parent_class)->constructed (object);
-
-	load_accels ();
-}
-
 static gboolean
 window_delete_event (GeditWindow *window,
                      GdkEvent    *event,
@@ -1142,7 +1141,6 @@ gedit_app_class_init (GeditAppClass *klass)
 
 	object_class->dispose = gedit_app_dispose;
 	object_class->get_property = gedit_app_get_property;
-	object_class->constructed = gedit_app_constructed;
 
 	app_class->startup = gedit_app_startup;
 	app_class->activate = gedit_app_activate;
