@@ -91,10 +91,10 @@ GType 		 gedit_app_get_type 			(void) G_GNUC_CONST;
 GeditWindow	*gedit_app_create_window		(GeditApp    *app,
 							 GdkScreen   *screen);
 
-/* Returns a newly allocated list with all the documents */
+GList		*gedit_app_get_main_windows		(GeditApp    *app);
+
 GList		*gedit_app_get_documents		(GeditApp    *app);
 
-/* Returns a newly allocated list with all the views */
 GList		*gedit_app_get_views			(GeditApp    *app);
 
 /* Lockdown state */
@@ -137,6 +137,10 @@ GObject			*_gedit_app_get_settings		(GeditApp  *app);
 
 GMenuModel		*_gedit_app_get_window_menu		(GeditApp  *app);
 
+GMenuModel		*_gedit_app_get_notebook_menu		(GeditApp  *app);
+
+GMenuModel		*_gedit_app_get_tab_width_menu		(GeditApp  *app);
+
 GeditMenuExtension	*_gedit_app_extend_menu			(GeditApp    *app,
 								 const gchar *extension_point);
 
