@@ -450,6 +450,7 @@ build_single_doc_dialog (GeditCloseConfirmationDialog *dlg)
 	gtk_misc_set_alignment (GTK_MISC (primary_label), 0.5, 0);
 	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
 	gtk_widget_set_can_focus (primary_label, FALSE);
+	gtk_label_set_max_width_chars (GTK_LABEL (primary_label), 72);
 
 	doc_name = gedit_document_get_short_name_for_display (doc);
 
@@ -490,6 +491,7 @@ build_single_doc_dialog (GeditCloseConfirmationDialog *dlg)
 	gtk_misc_set_alignment (GTK_MISC (secondary_label), 0.5, 0);
 	gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
 	gtk_widget_set_can_focus (secondary_label, FALSE);
+	gtk_label_set_max_width_chars (GTK_LABEL (secondary_label), 72);
 
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 10);
@@ -639,6 +641,7 @@ build_multiple_docs_dialog (GeditCloseConfirmationDialog *dlg)
 	gtk_misc_set_alignment (GTK_MISC (primary_label), 0.5, 0);
 	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
 	gtk_widget_set_can_focus (primary_label, FALSE);
+	gtk_label_set_max_width_chars (GTK_LABEL (primary_label), 72);
 
 	if (priv->disable_save_to_disk)
 	{
@@ -680,6 +683,7 @@ build_multiple_docs_dialog (GeditCloseConfirmationDialog *dlg)
 
 	gtk_box_pack_start (GTK_BOX (vbox2), select_label, FALSE, FALSE, 0);
 	gtk_label_set_line_wrap (GTK_LABEL (select_label), TRUE);
+	gtk_label_set_max_width_chars (GTK_LABEL (select_label), 72);
 	gtk_widget_set_halign (select_label, GTK_ALIGN_START);
 
 	scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
@@ -708,6 +712,7 @@ build_multiple_docs_dialog (GeditCloseConfirmationDialog *dlg)
 	gtk_widget_set_valign (secondary_label, GTK_ALIGN_START);
 	gtk_misc_set_alignment (GTK_MISC (secondary_label), 0.5, 0);
 	gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
+	gtk_label_set_max_width_chars (GTK_LABEL (secondary_label), 72);
 
 	gtk_label_set_mnemonic_widget (GTK_LABEL (select_label), treeview);
 
