@@ -17,17 +17,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
- */
-
-/*
- * Modified by the gedit Team, 1998-2005. See the AUTHORS file for a
- * list of people on the gedit Team.
- * See the ChangeLog files for a list of changes.
- *
- * $Id$
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __GEDIT_UTILS_H__
@@ -63,14 +53,6 @@ void		 gedit_utils_menu_position_under_tree_view
 							 gboolean         *push_in,
 							 gpointer          user_data);
 
-GtkWidget	*gedit_gtk_button_new_with_stock_icon	(const gchar      *label,
-							 const gchar      *stock_id);
-
-GtkWidget	*gedit_dialog_add_button		(GtkDialog        *dialog,
-							 const gchar      *text,
-							 const gchar      *stock_id,
-							 gint              response_id);
-
 gchar		*gedit_utils_escape_underscores		(const gchar      *text,
 							 gssize            length);
 
