@@ -21,6 +21,7 @@ from gi.repository import GObject, Gio, GLib, Gtk, Gedit
 from .virtualdirs import RecentDocumentsDirectory
 from .virtualdirs import CurrentDocumentsDirectory
 
+
 class QuickOpenAppActivatable(GObject.Object, Gedit.AppActivatable):
     app = GObject.property(type=Gedit.App)
 
@@ -37,6 +38,7 @@ class QuickOpenAppActivatable(GObject.Object, Gedit.AppActivatable):
     def do_deactivate(self):
         self.app.remove_accelerator("win.quickopen", None)
 
+
 class QuickOpenPlugin(GObject.Object, Gedit.WindowActivatable):
     __gtype_name__ = "QuickOpenPlugin"
 
@@ -119,7 +121,7 @@ class QuickOpenPlugin(GObject.Object, Gedit.WindowActivatable):
 
         paths = []
 
-        for line in open(filename, 'r'):
+        for line in open(filename, 'r', encoding='utf-8'):
             uri = line.strip().split(" ")[0]
             f = Gio.file_new_for_uri(uri)
 
@@ -146,12 +148,13 @@ class QuickOpenPlugin(GObject.Object, Gedit.WindowActivatable):
         desktopdir = None
 
         if os.path.isfile(config):
-            for line in open(config, 'r'):
+            for line in open(config, 'r', encoding='utf-8'):
                 line = line.strip()
 
                 if line.startswith('XDG_DESKTOP_DIR'):
                     parts = line.split('=', 1)
-                    desktopdir = os.path.expandvars(parts[1].strip('"').strip("'"))
+                    desktopdir = parts[1].strip('"').strip("'")
+                    desktopdir = os.path.expandvars(desktopdir)
                     break
 
         if not desktopdir:
